@@ -178,7 +178,7 @@ None by default.
 
 =head1 AUTHOR
 
-Mathias Weidner, E<lt>mathias@weidner.in-bad-schmiedeberg.deE<gt>
+Mathias Weidner, C<< <mamawe@cpan.org> >>
 
 =head1 SEE ALSO
 
